% export a new document class
% (based on the standard "report" class)
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{vcthesis}[2022/07/15]
\DeclareOption*{\PassOptionsToClass{\CurrentOption,11pt, twoside, openright, a4paper}{report}}
\ProcessOptions

\LoadClass{report}

% required packages
\AtEndOfPackage{
\RequirePackage[utf8]{inputenc}
\RequirePackage{a4wide}
\RequirePackage[backend=biber,style=numeric,bibencoding=utf8,natbib=true]{biblatex}
\addbibresource{bibliography.bib}
}

% page setup
\setlength{\textwidth}{6.5in}
\setlength{\hoffset}{0pt}
\setlength{\evensidemargin}{0in}
\setlength{\oddsidemargin}{\paperwidth}
\addtolength{\oddsidemargin}{-1in}
\addtolength{\oddsidemargin}{-\evensidemargin}
\addtolength{\oddsidemargin}{-\textwidth}
\addtolength{\oddsidemargin}{-1in}
\setlength{\marginparwidth}{0.90in}
\setlength{\marginparsep}{0.10in}
\setlength{\textheight}{8in}
\setlength{\topmargin}{0pt}
\addtolength{\headheight}{12pt}
\setlength{\headsep}{20pt}
\renewcommand{\topfraction}{0.999}
\renewcommand{\textfraction}{0.001}
\setcounter{topnumber}{10}
\setcounter{dbltopnumber}{10}
\setcounter{totalnumber}{10}
\renewcommand{\dbltopfraction}{0.999}
\renewcommand{\dblfloatpagefraction}{0.999}
\renewcommand{\baselinestretch}{1.1}

% numbering schemes
\def\prepages{\normalfont\pagenumbering{roman}}
\def\mainbody{\pagenumbering{arabic}}

% title page macros
\newcommand\thesistype[1]{\gdef\@thesistype{#1}}
\newcommand\birthday[1]{\gdef\@birthday{#1}}
\newcommand\birthplace[1]{\gdef\@birthplace{#1}}
\newcommand\supervisor[1]{\gdef\@supervisor{#1}}
\newcommand\mentor[1]{\gdef\@mentor{Mentor: #1}}
\newcommand\bdate[1]{\gdef\@bdate{#1}}
\newcommand\edate[1]{\gdef\@edate{#1}}
\gdef\@thesistype{$<$TYPE OF THESIS$>$}
\gdef\@title{$<$TITLE$>$}
\gdef\@author{$<$AUTHOR$>$}
\gdef\@birthday{$<$BIRTHDAY$>$}
\gdef\@birthplace{$<$BIRTHPLACE$>$}
\gdef\@supervisor{$<$SUPERVISOR$>$}
\gdef\@mentor{}
\gdef\@bdate{$<$BEGINNING OF THESIS$>$}
\gdef\@edate{$<$END OF THESIS$>$}

% title page in English
\renewcommand{\maketitle}{%
\begin{titlepage} \setlength{\parindent}{0pt}
\thispagestyle{empty}
\begin{center}
{\LARGE\bf\@title}
\vspace{1.50cm}

{\large \@thesistype\ in Computer Science}
\vspace{1.50cm}

{\small presented by}\bigskip

{\bf\@author}\bigskip

born\ on \@birthday\ in \@birthplace\bigskip
\vspace{1.5cm}

{\small submitted to}\bigskip

{\bf Department of Computer Science\\
Professorship for Visual Computing\\
Friedrich-Alexander-Universit\"at Erlangen-N\"urnberg}
\vfill

Supervisor: \@supervisor\\
\bigskip
\@mentor
\vfill
\vfill

Begin date:\ \@bdate\bigskip

End date:\ \@edate
\vfill

\end{center}
\newpage
\end{titlepage}
}

% declaration in English
\newcommand{\declaration}{%
\parindent0pt
\chapter*{Declaration}
\bigskip

I certify that I have written this thesis without outside help and without using sources other than those indicated, and that the thesis has not been submitted in the same or similar form to any other examination authority and has not been accepted by them as part of an examination. All statements that have been taken over verbatim or in spirit are marked as such.

\bigskip
I agree that the thesis may be published and that it may be referred to in scientific publications.

\bigskip
The Friedrich-Alexander-Universit\"at Erlangen-N\"urnberg, represented by the Professorship for Visual Computing, is granted a (non-exclusive) right to use this work and the programs created in connection with it.

\vskip3cm
Erlangen, \@edate \hfill

\hfill{\vbox{\hrule{\hbox{\strut$\qquad$\small(\@author)$\qquad$}}}}
\thispagestyle{empty}
}


\DeclareOption{german}{
% enable German chapter captions
\AtEndOfPackage{
\RequirePackage{csquotes}
\RequirePackage[ngerman]{babel}    
}
\renewcommand\mentor[1]{\gdef\@mentor{Betreuender Hochschullehrer: #1}}
% title page in German
\renewcommand{\maketitle}{%
\begin{titlepage} \setlength{\parindent}{0pt}
\thispagestyle{empty}
\begin{center}
{\LARGE\bf\@title}
\vspace{1.50cm}

{\large \@thesistype\ in Informatik}
\vspace{1.50cm}

{\small vorgelegt von}\bigskip

{\bf\@author}\bigskip

geb.\ am \@birthday\ in \@birthplace\bigskip
\vspace{1.5cm}

{\small angefertig am}\bigskip

{\bf Department Informatik\\
Professur f{\"u}r Visual Computing\\
Friedrich-Alexander-Universit\"at Erlangen-N\"urnberg}
\vfill

Betreuer: \@supervisor\\
\bigskip
\@mentor
\vfill
\vfill

Beginn der Arbeit:\ \@bdate\bigskip

Ende der Arbeit:\ \@edate
\vfill

\end{center}
\newpage
\end{titlepage}
}

% declaration in German
\renewcommand{\declaration}{%
\parindent0pt
\chapter*{Erkl\"arung}
\bigskip

Ich versichere, dass ich die Arbeit ohne fremde Hilfe und ohne Benutzung
anderer als der angegebenen Quellen angefertigt habe und dass die Arbeit in
gleicher oder \"ahnlicher Form noch keiner anderen Pr\"ufungsbeh\"orde
vorgelegen hat und von dieser als Teil einer Pr\"ufungsleistung angenommen
wurde. Alle Ausf\"uhrungen, die w\"ortlich oder sinngem\"a\ss\ \"ubernommen
wurden, sind als solche gekennzeichnet.

\bigskip
Ich bin damit einverstanden, dass die Arbeit ver\"offentlicht wird und
dass in wissenschaftlichen Ver\-\"offent\-lich\-ungen auf sie Bezug genommen wird.

\bigskip
Der Friedrich-Alexander-Universit\"at Erlangen-N\"urnberg, vertreten durch die Professur f{\"u}r Visual Computing, wird ein (nicht ausschlie\ss liches)
Nutzungsrecht an dieser Arbeit sowie an den im Zusammenhang mit ihr
erstellten Programmen einger\"aumt.

\vskip3cm
Erlangen, den \@edate \hfill

\hfill{\vbox{\hrule{\hbox{\strut$\qquad$\small(\@author)$\qquad$}}}}
\thispagestyle{empty}
}
}
\ProcessOptions\relax